@@ -1,5 +1,5 @@
 
-medCMA <- function(df=data,followUpDays=365) {
+medCMA <- function(df=data,followUpDays=365, digits=2) {
    n <- length(unique(df$id))
    aseq <- numeric(n)
    rxmax <- dim(df)[[1]]/n
@@ -11,7 +11,7 @@ medCMA <- function(df=data,followUpDays=365) {
    #rownames(ndt) <- NULL
    names(ndt) <- c("id","daySupplies")
    ndt$followUpDays <- followUpDays
-   ndt$CMA <- round(ndt$daySupplies / ndt$followUpDays*100,1)
+   ndt$CMA <- round(ndt$daySupplies / ndt$followUpDays*100,digits)
    return(ndt)
   }
   
